package WebGUI::i18n::Spanish::Asset_Product;
use utf8;
our $I18N = {
  10 => {
    'lastUpdated' => '1253412014',
    'message' => 'Precio'
  },
  '10 description' => {
    'lastUpdated' => '1253412020',
    'message' => 'El precio de esta variante.'
  },
  13 => {
    'lastUpdated' => '1253412073',
    'message' => 'Folleto'
  },
  '13 description' => {
    'lastUpdated' => '1253412085',
    'message' => 'El Folleto para este Producto.'
  },
  14 => {
    'lastUpdated' => '1253412089',
    'message' => 'Manual'
  },
  '14 description' => {
    'lastUpdated' => '1253412118',
    'message' => 'El Manual de Usuario o de Servicio, para este Producto.'
  },
  15 => {
    'lastUpdated' => '1253412123',
    'message' => 'Garantía'
  },
  '15 description' => {
    'lastUpdated' => '1253412134',
    'message' => 'La Garantía de este Producto.'
  },
  16 => {
    'lastUpdated' => '1253412139',
    'message' => 'Agregar Accesorio'
  },
  17 => {
    'lastUpdated' => '1253412146',
    'message' => 'Accesorio'
  },
  '17 description' => {
    'lastUpdated' => '1253412282',
    'message' => 'Seleccione de la lista de Productos existentes.'
  },
  18 => {
    'lastUpdated' => '1253412188',
    'message' => '¿Agregar otro Accesorio?'
  },
  '18 description' => {
    'lastUpdated' => '1253412222',
    'message' => 'Indique si tiene algún Accesorio adicional por agregar.'
  },
  19 => {
    'lastUpdated' => '1253412236',
    'message' => 'Agregar Producto relacionado'
  },
  2 => {
    'lastUpdated' => '1253412253',
    'message' => '¿Está seguro que quiere eliminar la relación con este Accesorio?'
  },
  20 => {
    'lastUpdated' => '1253412264',
    'message' => 'Producto Relacionado'
  },
  '20 description' => {
    'lastUpdated' => '1253412288',
    'message' => 'Seleccione de la lista de Productos existentes.'
  },
  21 => {
    'lastUpdated' => '1253412300',
    'message' => '¿Agregar otro Producto relacionado?'
  },
  '21 description' => {
    'lastUpdated' => '1253412313',
    'message' => 'Indique si tiene otro producto Relacionado por agregar.'
  },
  22 => {
    'lastUpdated' => '1253412326',
    'message' => 'Editar Característica'
  },
  23 => {
    'lastUpdated' => '1253412334',
    'message' => 'Característica'
  },
  '23 description' => {
    'lastUpdated' => '1253412370',
    'message' => 'Puede agregar una característica adicional o seleccionar alguna que ya haya sido incluida con otro Producto del sistema.'
  },
  24 => {
    'lastUpdated' => '1253412380',
    'message' => '¿Agregar otra característica?'
  },
  '24 description' => {
    'lastUpdated' => '1253412448',
    'message' => 'Indique si desea agregar una característica adicional.'
  },
  25 => {
    'lastUpdated' => '1253412458',
    'message' => 'Editar Especificación'
  },
  26 => {
    'lastUpdated' => '1253412464',
    'message' => 'Etiqueta'
  },
  '26 description' => {
    'lastUpdated' => '1253412500',
    'message' => 'El tipo de especificación. Por ejemplo, altura, peso o color. Puede seleccionar cualquiera que haya sido definida para otro Producto o bien definir una nueva.'
  },
  27 => {
    'lastUpdated' => '1253412507',
    'message' => 'Especificación'
  },
  '27 description' => {
    'lastUpdated' => '1253412546',
    'message' => 'El valor de la especificación particular. Por ejemplo, si introduce "Peso" como Etiqueta, entonces debería introducir un valor numérico como "42".'
  },
  28 => {
    'lastUpdated' => '1253412567',
    'message' => '¿Agregar otra especificación?'
  },
  '28 description' => {
    'lastUpdated' => '1253412680',
    'message' => 'Indique si desea agregar una especificación adicional.'
  },
  29 => {
    'lastUpdated' => '1253412687',
    'message' => 'Unidades'
  },
  '29 description' => {
    'lastUpdated' => '1253412727',
    'message' => 'La unidad de medida para esta especificación. Por ejemplo, si seleccionó "Peso" para la Etiqueta, quizás sería apropiado usar "Kilos" como unidad.'
  },
  3 => {
    'lastUpdated' => '1253412745',
    'message' => '¿Está seguro que desea eliminar esta Característica?'
  },
  30 => {
    'lastUpdated' => '1253412752',
    'message' => 'Características'
  },
  31 => {
    'lastUpdated' => '1253412759',
    'message' => 'Especificaciones'
  },
  32 => {
    'lastUpdated' => '1253412764',
    'message' => 'Accesorios'
  },
  33 => {
    'lastUpdated' => '1253412771',
    'message' => 'Productos Relacionados'
  },
  34 => {
    'lastUpdated' => '1253412784',
    'message' => 'Agregar Característica.'
  },
  35 => {
    'lastUpdated' => '1253412792',
    'message' => 'Agregar Especificación.'
  },
  36 => {
    'lastUpdated' => '1253412800',
    'message' => 'Agregar Accesorio.'
  },
  37 => {
    'lastUpdated' => '1253412808',
    'message' => 'Agregar Producto Relacionado'
  },
  4 => {
    'lastUpdated' => '1253412824',
    'message' => '¿Está seguro que quiere eliminar la relación con este Producto?'
  },
  48 => {
    'lastUpdated' => '1253412840',
    'message' => '¿Está seguro que quiere eliminar este Beneficio?'
  },
  5 => {
    'lastUpdated' => '1253412886',
    'message' => '¿Está seguro que quiere eliminar esta Especificación?'
  },
  51 => {
    'lastUpdated' => '1253412893',
    'message' => 'Beneficio'
  },
  '51 description' => {
    'lastUpdated' => '1253412912',
    'message' => 'Puede ingresar un nuevo beneficio o seleccionar alguno ingresado previamente.'
  },
  52 => {
    'lastUpdated' => '1253412970',
    'message' => '¿Agregar otro Beneficio?'
  },
  '52 description' => {
    'lastUpdated' => '1253412981',
    'message' => 'Indique si desea agregar un Beneficio adicional.'
  },
  53 => {
    'lastUpdated' => '1253412989',
    'message' => 'Editar Beneficio'
  },
  54 => {
    'lastUpdated' => '1253412995',
    'message' => 'Beneficios'
  },
  55 => {
    'lastUpdated' => '1253413003',
    'message' => 'Agregar un Beneficio'
  },
  56 => {
    'lastUpdated' => '1253413012',
    'message' => 'Agregar una Plantilla de Producto'
  },
  57 => {
    'lastUpdated' => '1253413039',
    'message' => '¿Está seguro que quiere eliminar esta Plantilla y que todos los productos que la utilizan pasen a emplear la Plantilla por defecto?'
  },
  58 => {
    'lastUpdated' => '1253413053',
    'message' => 'Plantilla para Editar Producto'
  },
  59 => {
    'lastUpdated' => '1253413058',
    'message' => 'Nombre'
  },
  6 => {
    'lastUpdated' => '1253413063',
    'message' => 'Editar Producto'
  },
  60 => {
    'lastUpdated' => '1253413069',
    'message' => 'Plantilla'
  },
  62 => {
    'lastUpdated' => '1253413078',
    'message' => 'Plantilla de Producto'
  },
  '62 description' => {
    'lastUpdated' => '1253413095',
    'message' => 'Seleccione la Plantilla para desplegar este Producto.'
  },
  7 => {
    'lastUpdated' => '1253413119',
    'message' => 'Imagen #1 del Producto'
  },
  '7 description' => {
    'lastUpdated' => '1253413128',
    'message' => 'Una imagen de este Producto.'
  },
  8 => {
    'lastUpdated' => '1253413136',
    'message' => 'Imagen #2 del Producto'
  },
  '8 description' => {
    'lastUpdated' => '1253413148',
    'message' => 'Una imagen de este Producto.'
  },
  9 => {
    'lastUpdated' => '1253413163',
    'message' => 'Imagen #3 del Producto'
  },
  '9 description' => {
    'lastUpdated' => '1253413182',
    'message' => 'Una imagen de este Producto.'
  },
  'Controls' => {
    'lastUpdated' => '1253413190',
    'message' => 'Controles'
  },
  'Lost' => {
    'lastUpdated' => '1302873426',
    'message' => 'Activo Perdido'
  },
  'accessory_controls' => {
    'lastUpdated' => '1253413204',
    'message' => 'Los controles administrativos WebGUI para este Accesorio.'
  },
  'accessory_loop' => {
    'lastUpdated' => '1253413217',
    'message' => 'Un ciclo que itera sobre los Accesorios asociados a este Producto.'
  },
  'accessory_title' => {
    'lastUpdated' => '1253413231',
    'message' => 'El Título del Accesorio enlazado.'
  },
  'accessory_url' => {
    'lastUpdated' => '1253413242',
    'message' => 'El URL al Accesorio enlazado.'
  },
  'add a variant' => {
    'lastUpdated' => '1253413248',
    'message' => 'Agregar una Variante'
  },
  'add another variant' => {
    'lastUpdated' => '1253413256',
    'message' => '¿Agregar otra Variante?'
  },
  'add another variant description' => {
    'lastUpdated' => '1253413272',
    'message' => 'Indique si desea agregar una Variante adicional.'
  },
  'add to cart' => {
    'lastUpdated' => '1253413281',
    'message' => 'Agregar al Carrito'
  },
  'add variant' => {
    'lastUpdated' => '1253413288',
    'message' => 'Agregar Variante'
  },
  'addRelatedProduct_label' => {
    'lastUpdated' => '1253413310',
    'message' => 'La etiqueta para el enlace de agregar Productos relacionados.'
  },
  'addRelatedProduct_url' => {
    'lastUpdated' => '1253413327',
    'message' => 'El URL para agregar un Producto relacionado a este Producto.'
  },
  'addaccessory_label' => {
    'lastUpdated' => '1253413342',
    'message' => 'La etiqueta para el enlace de agregar un Accesorio.'
  },
  'addaccessory_url' => {
    'lastUpdated' => '1253413352',
    'message' => 'El URL para agregar un Accesorio a este Producto.'
  },
  'addbenefit_label' => {
    'lastUpdated' => '1253413364',
    'message' => 'La etiqueta para el enlace de agregar Beneficio.'
  },
  'addbenefit_url' => {
    'lastUpdated' => '1253413373',
    'message' => 'El URL para agregar un Beneficio a este Producto.'
  },
  'addfeature_label' => {
    'lastUpdated' => '1253413387',
    'message' => 'La etiqueta para el enlace de agregar una Característica.'
  },
  'addfeature_url' => {
    'lastUpdated' => '1253413398',
    'message' => 'El URL para agregar una Característica a este Producto.'
  },
  'addspecification_label' => {
    'lastUpdated' => '1253413419',
    'message' => 'La etiqueta para el enlace de agregar Especificación.'
  },
  'addspecification_url' => {
    'lastUpdated' => '1253413429',
    'message' => 'El URL para agregar una Especificación a este Producto.'
  },
  'addvariant_label' => {
    'lastUpdated' => '1253413462',
    'message' => 'Etiqueta para el enlace de agregar Variante.'
  },
  'addvariant_url' => {
    'lastUpdated' => '1253413476',
    'message' => 'El URL para agregar Variantes a este Producto.'
  },
  'assetName' => {
    'lastUpdated' => '1253413481',
    'message' => 'Producto'
  },
  'benefit_benefit' => {
    'lastUpdated' => '1253413492',
    'message' => 'El texto que describe el Beneficio.'
  },
  'benefit_controls' => {
    'lastUpdated' => '1253413504',
    'message' => 'Los controles administrativos WebGUI para este Beneficio.'
  },
  'benefit_loop' => {
    'lastUpdated' => '1253413514',
    'message' => 'Un ciclo que itera sobre los Beneficios de este Producto.'
  },
  'brochure' => {
    'lastUpdated' => '1253413533',
    'message' => 'El identificador único del objeto que almacena el Folleto de este Producto.'
  },
  'brochure_icon' => {
    'lastUpdated' => '1253413546',
    'message' => 'El URL para el ícono del Folleto.'
  },
  'brochure_label' => {
    'lastUpdated' => '1253413560',
    'message' => 'La etiqueta para el URL al Folleto.'
  },
  'brochure_url' => {
    'lastUpdated' => '1253413567',
    'message' => 'El URL para descargar el Folleto.'
  },
  'buy_form_button' => {
    'lastUpdated' => '1253413579',
    'message' => 'El botón de envío de la forma.'
  },
  'buy_form_footer' => {
    'lastUpdated' => '1253413636',
    'message' => 'El fragmento HTML que termina el formulario para agregar una Variante al Carrito.'
  },
  'buy_form_header' => {
    'lastUpdated' => '1253413624',
    'message' => 'El fragmento HTML que inicia el formulario para agregar una Variante al Carrito.'
  },
  'buy_form_options' => {
    'lastUpdated' => '1253413663',
    'message' => 'Una lista de Variantes disponibles para este Producto. Solamente se listarán las Variantes con cantidades mayores a cero.'
  },
  'cache timeout' => {
    'lastUpdated' => '1253413672',
    'message' => 'Tiempo Máximo en Cache'
  },
  'cache timeout help' => {
    'lastUpdated' => '1253413918',
    'message' => 'Como todos los usuarios ven este Activo de la misma forma, puede mantenerse en cache por un tiempo para mejorar el desempeño del sistema. ¿Cuánto tiempo debemos mantenerlo en el cache?'
  },
  'cacheTimeout' => {
    'lastUpdated' => '1253413938',
    'message' => 'El tiempo en segundos que la presentación de este Activo permanecerá en cache.'
  },
  'canEdit' => {
    'lastUpdated' => '1253413949',
    'message' => 'Un condicional que indica si el usaurio puede editar este Producto.'
  },
  'continueShoppingUrl' => {
    'lastUpdated' => '1253413971',
    'message' => 'Un URL para restablecer el Producto de manera que el usuario pueda seguir comprando.'
  },
  'default thank you message' => {
    'lastUpdated' => '1253413982',
    'message' => '!Gracias por su compra!'
  },
  'delete variant confirm' => {
    'lastUpdated' => '1253413993',
    'message' => '¿Está seguro que desea eliminar esta Variante?'
  },
  'deleteImage' => {
    'lastUpdated' => '1253414003',
    'message' => 'Eliminar archivo adjunto'
  },
  'feature_controls' => {
    'lastUpdated' => '1253414017',
    'message' => 'Los controles administrativos WebGUI para esta Característica.'
  },
  'feature_feature' => {
    'lastUpdated' => '1253414026',
    'message' => 'El nombre de la Característica.'
  },
  'feature_loop' => {
    'lastUpdated' => '1253414057',
    'message' => 'Un ciclo que itera sobre todas las Características asociadas con este Producto.'
  },
  'hasAddedToCart' => {
    'lastUpdated' => '1253414085',
    'message' => 'Un condicional que indica si el usuario ha agregado el Producto a su Carrito, para poder presentar el mensaje de agradecimiento.'
  },
  'image1' => {
    'lastUpdated' => '1253414116',
    'message' => 'El identificador único del objeto de almacenamiento para la Imagen #1'
  },
  'image2' => {
    'lastUpdated' => '1253414127',
    'message' => 'El identificador único del objeto de almacenamiento para la Imagen #2'
  },
  'image3' => {
    'lastUpdated' => '1253414146',
    'message' => 'El identificador único del objeto de almacenamiento para la Imagen #3'
  },
  'in_stock' => {
    'lastUpdated' => '1253414178',
    'message' => 'Un condicional que indica si hay Variantes disponibles de este Producto para la venta.'
  },
  'isShippingRequired' => {
    'lastUpdated' => '1253414210',
    'message' => '¿Requiere envío?'
  },
  'isShippingRequired help' => {
    'lastUpdated' => '1253414245',
    'message' => 'Determina si los costos de envio serán calculados cuando el usuario cierre la transacción.'
  },
  'manual' => {
    'lastUpdated' => '1253414262',
    'message' => 'El identificador único del objeto de almacenamiento para el Manual del Producto.'
  },
  'manual_icon' => {
    'lastUpdated' => '1253414276',
    'message' => 'El URL al ícono para el Manual.'
  },
  'manual_label' => {
    'lastUpdated' => '1253414298',
    'message' => 'La etiqueta para el URL hacia el Manual.'
  },
  'manual_url' => {
    'lastUpdated' => '1253414319',
    'message' => 'El URL para descargar el Manual.'
  },
  'no_stock_message' => {
    'lastUpdated' => '1253414365',
    'message' => 'Un mensaje que indica que no quedan Variantes de este producto disponibles para la venta.'
  },
  'options' => {
    'lastUpdated' => '1253414388',
    'message' => 'Opciones'
  },
  'other products' => {
    'lastUpdated' => '1253414394',
    'message' => 'Otros Productos'
  },
  'out of stock' => {
    'lastUpdated' => '1253414420',
    'message' => 'Agotado'
  },
  'price' => {
    'lastUpdated' => '1253414430',
    'message' => 'El precio de este Producto'
  },
  'product asset template variables body' => {
    'lastUpdated' => '1253414469',
    'message' => 'Cada Activo provee un conjunto de variables accesibles desde las Plantillas y que están basadas en las propiedades internas del Activo. Algunas variables son más útiles que otras.'
  },
  'product asset template variables title' => {
    'lastUpdated' => '1253414489',
    'message' => 'Variables para Plantilla de Productos'
  },
  'quantity' => {
    'lastUpdated' => '1253414494',
    'message' => 'Cantidad'
  },
  'quantity description' => {
    'lastUpdated' => '1253414527',
    'message' => 'Indica cuantas unidades de esta Variante están disponibles.'
  },
  'relatedproduct_controls' => {
    'lastUpdated' => '1253414571',
    'message' => 'Los controles administrativos WebGUI para este Producto relacionado.'
  },
  'relatedproduct_loop' => {
    'lastUpdated' => '1253414589',
    'message' => 'Un ciclo que itera sobre todos los Productos relacionados con este Producto.'
  },
  'relatedproduct_title' => {
    'lastUpdated' => '1253414600',
    'message' => 'El Título del Producto relacionado.'
  },
  'relatedproduct_url' => {
    'lastUpdated' => '1253414609',
    'message' => 'El URL al Producto relacionado.'
  },
  'shortdesc' => {
    'lastUpdated' => '1253414617',
    'message' => 'Descripción Corta'
  },
  'shortdesc description' => {
    'lastUpdated' => '1253414678',
    'message' => 'La Descripción Corta tiene un límite de 30 caracteres de longitud.'
  },
  'specification_controls' => {
    'lastUpdated' => '1253414693',
    'message' => 'Los controles administrativos WebGUI para esta Especificación.'
  },
  'specification_label' => {
    'lastUpdated' => '1253414704',
    'message' => 'La etiqueta para esta Especificación. ej: peso'
  },
  'specification_loop' => {
    'lastUpdated' => '1253414717',
    'message' => 'Un ciclo que itera sobre todas las Especificaciones asociadas a este Producto.'
  },
  'specification_specification' => {
    'lastUpdated' => '1253414726',
    'message' => 'El texto de la Especificación.'
  },
  'specification_units' => {
    'lastUpdated' => '1253414746',
    'message' => 'Las unidades para esta Especificación, por ejemplo, kilos'
  },
  'specs' => {
    'lastUpdated' => '1253414759',
    'message' => 'Especif.'
  },
  'templateId' => {
    'lastUpdated' => '1253414772',
    'message' => 'El ID de la Plantilla que será utilizada para desplegar este Activo.'
  },
  'thank you message' => {
    'lastUpdated' => '1253414777',
    'message' => 'Mensaje de Agradecimiento'
  },
  'thank you message help' => {
    'lastUpdated' => '1253414816',
    'message' => 'Escriba un mensaje de agradecimiento para los usuarios que compran algo en su sitio. Sea sincero, porque de lo contrario pueden cancelar la compra e irse a Amazon.'
  },
  'thumbnail1' => {
    'lastUpdated' => '1253414837',
    'message' => 'El URL a la miniatura de la Imagen #1 para el Producto.'
  },
  'thumbnail2' => {
    'lastUpdated' => '1253414844',
    'message' => 'El URL a la miniatura de la Imagen #2 para el Producto.'
  },
  'thumbnail3' => {
    'lastUpdated' => '1253414852',
    'message' => 'El URL a la miniatura de la Imagen #3 para el Producto.'
  },
  'variant sku' => {
    'lastUpdated' => '1253414859',
    'message' => 'SKU'
  },
  'variant sku description' => {
    'lastUpdated' => '1253414887',
    'message' => 'Un identificador único para esta Variante del Producto. Debe ser la misma que se utiliza en su sistema de inventario para poder sincronizarlos.'
  },
  'variant_controls' => {
    'lastUpdated' => '1253414902',
    'message' => 'Una barra de íconos para editar, eliminar o reordenar esta Variante.'
  },
  'variant_id' => {
    'lastUpdated' => '1253414911',
    'message' => 'El identificador único para esta Variante.'
  },
  'variant_loop' => {
    'lastUpdated' => '1253414924',
    'message' => 'Un ciclo que itera sobre todas las Variantes de este Producto.'
  },
  'variant_price' => {
    'lastUpdated' => '1253414931',
    'message' => 'El precio de esta Variante.'
  },
  'variant_quantity' => {
    'lastUpdated' => '1253414942',
    'message' => 'La cantidad disponible de esta Variante.'
  },
  'variant_sku' => {
    'lastUpdated' => '1253414951',
    'message' => 'El SKU de esta Variante.'
  },
  'variant_title' => {
    'lastUpdated' => '1253414964',
    'message' => 'El Título o Descripción Corta de esta Variante.'
  },
  'variant_weight' => {
    'lastUpdated' => '1253414972',
    'message' => 'El peso de esta Variante.'
  },
  'variants' => {
    'lastUpdated' => '1253414977',
    'message' => 'Variantes'
  },
  'warranty' => {
    'lastUpdated' => '1253414998',
    'message' => 'El identificador único para el objeto de almacenamiento de la Garantía del Producto.'
  },
  'warranty_icon' => {
    'lastUpdated' => '1253415008',
    'message' => 'El URL al ícono para la Garantía.'
  },
  'warranty_label' => {
    'lastUpdated' => '1253415021',
    'message' => 'La etiqueta para el URL hacia la Garantía.'
  },
  'warranty_url' => {
    'lastUpdated' => '1253415033',
    'message' => 'El URL para descargar la Garantía.'
  },
  'weight' => {
    'lastUpdated' => '1253415037',
    'message' => 'Peso'
  },
  'weight description' => {
    'lastUpdated' => '1253415048',
    'message' => 'El Peso de esta Variante.'
  }
}
;

1;
